@@ -31,14 +31,14 @@ class Slider(WidgetBase):
 
         if self.curved:
             if self.vertical:
-                self.radius = self.width // 2
+                self.radius = self._width // 2
             else:
-                self.radius = self.height // 2
+                self.radius = self._height // 2
 
         if self.vertical:
-            self.handleRadius = kwargs.get('handleRadius', int(self.width / 1.3))
+            self.handleRadius = kwargs.get('handleRadius', int(self._width / 1.3))
         else:
-            self.handleRadius = kwargs.get('handleRadius', int(self.height / 1.3))
+            self.handleRadius = kwargs.get('handleRadius', int(self._height / 1.3))
 
     def listen(self, events):
         pressed = pygame.mouse.get_pressed()[0]
@@ -50,41 +50,41 @@ class Slider(WidgetBase):
 
             if self.selected:
                 if self.vertical:
-                    self.value = self.max - self.round((y - self.y) / self.height * self.max)
+                    self.value = self.max - self.round((y - self._y) / self._height * self.max)
                     self.value = max(min(self.value, self.max), self.min)
                 else:
-                    self.value = self.round((x - self.x) / self.width * self.max + self.min)
+                    self.value = self.round((x - self._x) / self._width * self.max + self.min)
                     self.value = max(min(self.value, self.max), self.min)
 
         else:
             self.selected = False
 
     def draw(self):
-        pygame.draw.rect(self.win, self.colour, (self.x, self.y, self.width, self.height))
+        pygame.draw.rect(self.win, self.colour, (self._x, self._y, self._width, self._height))
 
         if self.vertical:
             if self.curved:
-                pygame.draw.circle(self.win, self.colour, (self.x + self.width // 2, self.y), self.radius)
-                pygame.draw.circle(self.win, self.colour, (self.x + self.width // 2, self.y + self.height), self.radius)
-            circle = (self.x + self.width // 2,
-                      int(self.y + (self.max - self.value) / (self.max - self.min) * self.height))
+                pygame.draw.circle(self.win, self.colour, (self._x + self._width // 2, self._y), self.radius)
+                pygame.draw.circle(self.win, self.colour, (self._x + self._width // 2, self._y + self._height), self.radius)
+            circle = (self._x + self._width // 2,
+                      int(self._y + (self.max - self.value) / (self.max - self.min) * self._height))
         else:
             if self.curved:
-                pygame.draw.circle(self.win, self.colour, (self.x, self.y + self.height // 2), self.radius)
-                pygame.draw.circle(self.win, self.colour, (self.x + self.width, self.y + self.height // 2), self.radius)
-            circle = (int(self.x + (self.value - self.min) / (self.max - self.min) * self.width),
-                      self.y + self.height // 2)
+                pygame.draw.circle(self.win, self.colour, (self._x, self._y + self._height // 2), self.radius)
+                pygame.draw.circle(self.win, self.colour, (self._x + self._width, self._y + self._height // 2), self.radius)
+            circle = (int(self._x + (self.value - self.min) / (self.max - self.min) * self._width),
+                      self._y + self._height // 2)
 
         gfxdraw.filled_circle(self.win, *circle, self.handleRadius, self.handleColour)
         gfxdraw.aacircle(self.win, *circle, self.handleRadius, self.handleColour)
 
     def contains(self, x, y):
         if self.vertical:
-            handleX = self.x + self.width // 2
-            handleY = int(self.y + (self.max - self.value) / (self.max - self.min) * self.height)
+            handleX = self._x + self._width // 2
+            handleY = int(self._y + (self.max - self.value) / (self.max - self.min) * self._height)
         else:
-            handleX = int(self.x + (self.value - self.min) / (self.max - self.min) * self.width)
-            handleY = self.y + self.height // 2
+            handleX = int(self._x + (self.value - self.min) / (self.max - self.min) * self._width)
+            handleY = self._y + self._height // 2
 
         if math.sqrt((handleX - x) ** 2 + (handleY - y) ** 2) <= self.handleRadius:
             return True
